@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 #
-"""config registry module for autostart handling."""
-#
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
@@ -32,6 +30,8 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+"""UCR module for autostart handling."""
+
 from logging import getLogger
 from subprocess import PIPE, Popen
 
