@@ -1,8 +1,5 @@
 # -*- coding: utf-8 -*-
 #
-# Univention Configuration Registry
-#  config registry module  to trigger udev on changes in /etc/default/keyboard
-#
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
@@ -33,6 +30,8 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+"""UCR module to trigger udev on changes in /etc/default/keyboard."""
+
 import os
 
 
