@@ -1,9 +1,6 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
-# Univention Configuration Registry
-#  add and remove nfs shares from the LDAP directory to /etc/fstab
-#
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
@@ -34,39 +31,39 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+"Add/remove NFS mount points from LDAP to/from /etc/fstab and mount them"
+
 from __future__ import print_function
 
 import argparse
 import os
 import subprocess
 import sys
+from os.path import abspath, sep
+from typing import IO, List, Optional, Set, Tuple
 
 import ldap
 from ldap.filter import filter_format
 
-import univention.config_registry
 import univention.uldap
+from univention.config_registry import ucr
 from univention.lib import fstab
 from univention.lib.policy_result import PolicyResultFailed, policy_result
 
 
-configRegistry = univention.config_registry.ConfigRegistry()
-configRegistry.load()
 verbose = False
 simulate = False
 
-ldap_hostdn = configRegistry.get('ldap/hostdn')
-
 MAGIC_LDAP = '#LDAP Entry DN:'
 
 
-def debug(msg, out=sys.stderr):
+def debug(msg: str, out: IO[str] = sys.stderr) -> None:
     """Print verbose information 'msg' to 'out'."""
     if verbose:
         print(msg, file=out)
 
 
-def exit(result, message=None):
+def exit(result: int, message: Optional[str] = None) -> None:
     """Exit with optional error message."""
     script = os.path.basename(sys.argv[0])
     if message:
@@ -74,7 +71,7 @@ def exit(result, message=None):
     sys.exit(result)
 
 
-def query_policy(host_dn, server=None, password_file="/etc/machine.secret", verbose=False):
+def query_policy(host_dn: str, server: Optional[str] = None, password_file: str = "/etc/machine.secret", verbose: bool = False) -> Set[str]:
     """Get NFS shares from LDAP as per policy for dn."""
     debug('Retrieving policy for %s...\n' % (host_dn,))
     try:
@@ -86,11 +83,10 @@ def query_policy(host_dn, server=None, password_file="/etc/machine.secret", verb
     return set(results.get('univentionNFSMounts', []))
 
 
-def main():
+def main() -> None:
     # parse command line
-    description = "Add NFS mount points from LDAP to /etc/fstab and mount them"
-    parser = argparse.ArgumentParser(description=description)
-    parser.add_argument('--dn', default=configRegistry.get('ldap/hostdn'), help=argparse.SUPPRESS)
+    parser = argparse.ArgumentParser(description=__doc__)
+    parser.add_argument('--dn', default=ucr['ldap/hostdn'], help=argparse.SUPPRESS)
     parser.add_argument('-s', '--simulate', action='store_true', help='simulate and show values to be set')
     parser.add_argument('-v', '--verbose', action='store_true', help='print verbose information')
     args = parser.parse_args()
@@ -107,7 +103,7 @@ def main():
     mount(to_mount)
 
 
-def update_fstab(args, simulate):
+def update_fstab(args: argparse.Namespace, simulate: bool) -> Set[str]:
     """remove all nfs mounts from the fstab"""
     debug("Rewriting /etc/fstab...\n")
     current_fstab = fstab.File('/etc/fstab')
@@ -141,14 +137,14 @@ def update_fstab(args, simulate):
     return to_mount
 
 
-def get_nfs_data(nfs_mount, entries):
+def get_nfs_data(nfs_mount: str, entries: List[fstab.Entry]) -> Optional[Tuple[str, str, str]]:
     fields = nfs_mount.split(' ')  # dn_univentionShareNFS mount_point
     dn = fields[0]
-    fqdn = "%(hostname)s.%(domainname)s" % configRegistry
-    lo = univention.uldap.getMachineConnection()
     if not dn:
         debug('no dn, skipping\n')
-        return
+        return None
+
+    lo = univention.uldap.getMachineConnection()
     # get univention share host and path for dn
     try:
         result = lo.lo.search_s(
@@ -157,7 +153,7 @@ def get_nfs_data(nfs_mount, entries):
             'objectclass=*',
             attrlist=['univentionShareHost', 'univentionSharePath'])
     except ldap.NO_SUCH_OBJECT:
-        return
+        return None
 
     try:
         attributes = result[0][1]
@@ -165,31 +161,32 @@ def get_nfs_data(nfs_mount, entries):
         share_path = attributes['univentionSharePath'][0].decode('utf-8')
     except LookupError:
         debug('not found, skipping\n')
-        return
-
-    # skip share if from self
-    if share_host == fqdn:
-        debug('is self, skipping\n')
-        return
+        return None
 
     mp = fields[-1] or share_path
     # skip share if target already in fstab
     mount_points = [entry.mount_point for entry in entries]
     if mp in mount_points:
         debug('already mounted on %s, skipping\n' % mp)
-        return
+        return None
+
+    # skip share if to self
+    fqdn = "%(hostname)s.%(domainname)s" % ucr
+    if share_host == fqdn and overlap(share_path, mp):
+        debug('is self and %s overlaps %s, skipping\n' % (share_path, mp))
+        return None
 
     nfs_path_fqdn = "%s:%s" % (share_host, share_path)
     # skip share if the source is already in the fstab
     sources = [entry.spec for entry in entries]
     if nfs_path_fqdn in sources:
         debug('already mounted from %s, skipping\n' % nfs_path_fqdn)
-        return
+        return None
 
     # get the ip of the share_host
     hostname, _, domain = share_host.partition('.')
     if hostname and _ and domain:
-        result = lo.lo.search_s(configRegistry['ldap/base'], ldap.SCOPE_SUBTREE, filter_format('(&(relativeDomainName=%s)(zoneName=%s))', (hostname, domain)), attrlist=['aRecord'])
+        result = lo.lo.search_s(ucr['ldap/base'], ldap.SCOPE_SUBTREE, filter_format('(&(relativeDomainName=%s)(zoneName=%s))', (hostname, domain)), attrlist=['aRecord'])
         try:
             attributes = result[0][1]
             nfs_path_ip = "%s:%s" % (attributes['aRecord'][0].decode('ASCII'), share_path)
@@ -201,12 +198,32 @@ def get_nfs_data(nfs_mount, entries):
     # skip share if the source is already in the fstab
     if nfs_path_ip in sources:
         debug('already mounted from %s, skipping\n' % nfs_path_ip)
-        return
+        return None
 
     return dn, nfs_path_ip, mp
 
 
-def mount(to_mount):
+def overlap(path_a: str, path_b: str) -> bool:
+    """
+    Check if two paths overlap.
+
+    >>> overlap("/mnt/a", "/mnt/b")
+    False
+    >>> overlap("/mnt/a", "/mnt/aa")
+    False
+    >>> overlap("/mnt/a", "/mnt")
+    True
+    """
+    return all(
+        a == b
+        for a, b in zip(
+            abspath(path_a).split(sep),
+            abspath(path_b).split(sep),
+        )
+    )
+
+
+def mount(to_mount: Set[str]) -> None:
     """mount new NFS filesystems"""
     for mp in sorted(to_mount):
         if not os.path.exists(mp):
